From: Karolina Stolarek <karolina.stola...@oracle.com>

Update name to reflect the broader definition of structs/variables that are
stored (e.g. ratelimits). This is a preparatory patch for adding rate limit
support.

[bhelgaas: "aer_report" -> "aer_info"]
Signed-off-by: Karolina Stolarek <karolina.stola...@oracle.com>
Signed-off-by: Bjorn Helgaas <bhelg...@google.com>
Tested-by: Krzysztof Wilczyński <kwilczyn...@kernel.org>
Reviewed-by: Ilpo Järvinen <ilpo.jarvi...@linux.intel.com>
Reviewed-by: Kuppuswamy Sathyanarayanan 
<sathyanarayanan.kuppusw...@linux.intel.com>
---
 drivers/pci/pcie/aer.c | 46 +++++++++++++++++++++---------------------
 include/linux/pci.h    |  2 +-
 2 files changed, 24 insertions(+), 24 deletions(-)

diff --git a/drivers/pci/pcie/aer.c b/drivers/pci/pcie/aer.c
index 4cdcf0ebd86d..4f1bff0f000f 100644
--- a/drivers/pci/pcie/aer.c
+++ b/drivers/pci/pcie/aer.c
@@ -54,8 +54,8 @@ struct aer_rpc {
        DECLARE_KFIFO(aer_fifo, struct aer_err_source, AER_ERROR_SOURCES_MAX);
 };
 
-/* AER stats for the device */
-struct aer_stats {
+/* AER info for the device */
+struct aer_info {
 
        /*
         * Fields for all AER capable devices. They indicate the errors
@@ -377,7 +377,7 @@ void pci_aer_init(struct pci_dev *dev)
        if (!dev->aer_cap)
                return;
 
-       dev->aer_stats = kzalloc(sizeof(struct aer_stats), GFP_KERNEL);
+       dev->aer_info = kzalloc(sizeof(*dev->aer_info), GFP_KERNEL);
 
        /*
         * We save/restore PCI_ERR_UNCOR_MASK, PCI_ERR_UNCOR_SEVER,
@@ -398,8 +398,8 @@ void pci_aer_init(struct pci_dev *dev)
 
 void pci_aer_exit(struct pci_dev *dev)
 {
-       kfree(dev->aer_stats);
-       dev->aer_stats = NULL;
+       kfree(dev->aer_info);
+       dev->aer_info = NULL;
 }
 
 #define AER_AGENT_RECEIVER             0
@@ -537,10 +537,10 @@ static const char *aer_agent_string[] = {
 {                                                                      \
        unsigned int i;                                                 \
        struct pci_dev *pdev = to_pci_dev(dev);                         \
-       u64 *stats = pdev->aer_stats->stats_array;                      \
+       u64 *stats = pdev->aer_info->stats_array;                       \
        size_t len = 0;                                                 \
                                                                        \
-       for (i = 0; i < ARRAY_SIZE(pdev->aer_stats->stats_array); i++) {\
+       for (i = 0; i < ARRAY_SIZE(pdev->aer_info->stats_array); i++) { \
                if (strings_array[i])                                   \
                        len += sysfs_emit_at(buf, len, "%s %llu\n",     \
                                             strings_array[i],          \
@@ -551,7 +551,7 @@ static const char *aer_agent_string[] = {
                                             i, stats[i]);              \
        }                                                               \
        len += sysfs_emit_at(buf, len, "TOTAL_%s %llu\n", total_string, \
-                            pdev->aer_stats->total_field);             \
+                            pdev->aer_info->total_field);              \
        return len;                                                     \
 }                                                                      \
 static DEVICE_ATTR_RO(name)
@@ -572,7 +572,7 @@ aer_stats_dev_attr(aer_dev_nonfatal, dev_nonfatal_errs,
                     char *buf)                                         \
 {                                                                      \
        struct pci_dev *pdev = to_pci_dev(dev);                         \
-       return sysfs_emit(buf, "%llu\n", pdev->aer_stats->field);       \
+       return sysfs_emit(buf, "%llu\n", pdev->aer_info->field);        \
 }                                                                      \
 static DEVICE_ATTR_RO(name)
 
@@ -599,7 +599,7 @@ static umode_t aer_stats_attrs_are_visible(struct kobject 
*kobj,
        struct device *dev = kobj_to_dev(kobj);
        struct pci_dev *pdev = to_pci_dev(dev);
 
-       if (!pdev->aer_stats)
+       if (!pdev->aer_info)
                return 0;
 
        if ((a == &dev_attr_aer_rootport_total_err_cor.attr ||
@@ -623,28 +623,28 @@ static void pci_dev_aer_stats_incr(struct pci_dev *pdev,
        unsigned long status = info->status & ~info->mask;
        int i, max = -1;
        u64 *counter = NULL;
-       struct aer_stats *aer_stats = pdev->aer_stats;
+       struct aer_info *aer_info = pdev->aer_info;
 
        trace_aer_event(pci_name(pdev), (info->status & ~info->mask),
                        info->severity, info->tlp_header_valid, &info->tlp);
 
-       if (!aer_stats)
+       if (!aer_info)
                return;
 
        switch (info->severity) {
        case AER_CORRECTABLE:
-               aer_stats->dev_total_cor_errs++;
-               counter = &aer_stats->dev_cor_errs[0];
+               aer_info->dev_total_cor_errs++;
+               counter = &aer_info->dev_cor_errs[0];
                max = AER_MAX_TYPEOF_COR_ERRS;
                break;
        case AER_NONFATAL:
-               aer_stats->dev_total_nonfatal_errs++;
-               counter = &aer_stats->dev_nonfatal_errs[0];
+               aer_info->dev_total_nonfatal_errs++;
+               counter = &aer_info->dev_nonfatal_errs[0];
                max = AER_MAX_TYPEOF_UNCOR_ERRS;
                break;
        case AER_FATAL:
-               aer_stats->dev_total_fatal_errs++;
-               counter = &aer_stats->dev_fatal_errs[0];
+               aer_info->dev_total_fatal_errs++;
+               counter = &aer_info->dev_fatal_errs[0];
                max = AER_MAX_TYPEOF_UNCOR_ERRS;
                break;
        }
@@ -656,19 +656,19 @@ static void pci_dev_aer_stats_incr(struct pci_dev *pdev,
 static void pci_rootport_aer_stats_incr(struct pci_dev *pdev,
                                 struct aer_err_source *e_src)
 {
-       struct aer_stats *aer_stats = pdev->aer_stats;
+       struct aer_info *aer_info = pdev->aer_info;
 
-       if (!aer_stats)
+       if (!aer_info)
                return;
 
        if (e_src->status & PCI_ERR_ROOT_COR_RCV)
-               aer_stats->rootport_total_cor_errs++;
+               aer_info->rootport_total_cor_errs++;
 
        if (e_src->status & PCI_ERR_ROOT_UNCOR_RCV) {
                if (e_src->status & PCI_ERR_ROOT_FATAL_RCV)
-                       aer_stats->rootport_total_fatal_errs++;
+                       aer_info->rootport_total_fatal_errs++;
                else
-                       aer_stats->rootport_total_nonfatal_errs++;
+                       aer_info->rootport_total_nonfatal_errs++;
        }
 }
 
diff --git a/include/linux/pci.h b/include/linux/pci.h
index 0e8e3fd77e96..81a81dbfc873 100644
--- a/include/linux/pci.h
+++ b/include/linux/pci.h
@@ -346,7 +346,7 @@ struct pci_dev {
        u8              hdr_type;       /* PCI header type (`multi' flag masked 
out) */
 #ifdef CONFIG_PCIEAER
        u16             aer_cap;        /* AER capability offset */
-       struct aer_stats *aer_stats;    /* AER stats for this device */
+       struct aer_info *aer_info;      /* AER info for this device */
 #endif
 #ifdef CONFIG_PCIEPORTBUS
        struct rcec_ea  *rcec_ea;       /* RCEC cached endpoint association */
-- 
2.43.0


Reply via email to